Molecular Hamiltonians
======================

This subset of Hamiltonian functions is useful for simulating alkaline-earth
fluoride molecules like CaF, SrF, etc.

Note: The molecular Hamiltonians have the values of the Bohr and nuclear
magneton specified in MHz/G by default. To use `pylcp` default units, the Bohr
and nuclear magneton values must be overridden.

Overview
--------

.. currentmodule:: pylcp.hamiltonians.XFmolecules

.. autosummary::

    Xstate
    Astate
    dipoleXandAstates


Detailed functions
------------------

.. automodule:: pylcp.hamiltonians.XFmolecules
  :members:
